library valpi;

import 'dart:convert';

import 'package:http/http.dart' as http;
import 'package:valpi/players.dart';
import 'package:valpi/characters.dart';
import 'package:valpi/maps.dart';
import 'package:valpi/actId.dart';

class Valpi {
  final String apiKey;
  final String server;
  final String locale;
  final int verbose;
  Valpi(this.apiKey, this.server, {this.locale = "en-GB", this.verbose = 1});
  Future<http.Response> getData(String unEncodedPath) async {
    String hostUri =
        "https://$server.api.riotgames.com/$unEncodedPath?locale=$locale&api_key=$apiKey";
    if (verbose == 1 || verbose == 2) {
      print("Final Host URL: " + hostUri);
    }

    var response = await http.get(Uri.parse(hostUri),
        headers: {"api_key": apiKey, "locale": locale, "size": "200"});
    if (verbose == 2) {
      print("Status Code: " + response.statusCode.toString());
    }

    return response;
  }

  Future<http.Response> valContent() async {
    String unEncodedPath = "val/content/v1/contents";
    var response = await getData(unEncodedPath);
    return response;
  }

  Future<String> getValActId(int act) async {
    http.Response actIdContents = await valContent();
    String actIdData = actIdContents.body;

    var actIdObjsJson = jsonDecode(actIdData)['acts'] as List;
    List<ActId> actIdObjs =
        actIdObjsJson.map((actIdJson) => ActId.fromJson(actIdJson)).toList();
    String requiredId = actIdObjs[act].id;
    return requiredId;
  }

  Future<List<Players>> getValLeaderBoardPlayerData(int act) async {
    String requiredId = await getValActId(act);
    if (verbose == 1 || verbose == 2) {
      print("Aquired Act ID: " + requiredId);
    }

    String unEncodedPath = "val/ranked/v1/leaderboards/by-act/$requiredId";
    if (verbose == 1) {
      print("Currently followed path: " + unEncodedPath);
    }

    var response = await getData(unEncodedPath);
    var playerIdContents = response.body;
    var playerIdObjsJson = jsonDecode(playerIdContents)['players'] as List;
    List<Players> playerIdObjs = playerIdObjsJson
        .map((playerIdJson) => Players.fromJson(playerIdJson))
        .toList();
    return playerIdObjs;
  }

  Future<List<Players>> getValLeaderBoardDataByActId(String id) async {
    String unEncodedPath = "val/ranked/v1/leaderboards/by-act/$id";
    if (verbose == 2) {
      print("Currently followed path: " + unEncodedPath);
    }

    var response = await getData(unEncodedPath);
    var playerIdContents = response.body;
    var playerIdObjsJson = jsonDecode(playerIdContents)['players'] as List;
    List<Players> playerIdObjs = playerIdObjsJson
        .map((playerIdJson) => Players.fromJson(playerIdJson))
        .toList();
    return playerIdObjs;
  }

  Future<http.Response> valStatus() async {
    String unEncodedPath = "val/status/v1/platform-data";
    var response = await getData(unEncodedPath);
    if (verbose == 2) {
      print("Response recieved for valStatus(): " + response.body);
    }

    return response;
  }

  Future<List<String>> getAvailableLocales() async {
    http.Response response = await valStatus();
    var localesData = jsonDecode(response.body)["locales"];
    List<String> locales = localesData != null ? List.from(localesData) : null;
    return locales;
  }

  Future<String> getServerId() async {
    http.Response response = await valStatus();
    var responseJson = response.body;
    var responseData = jsonDecode(responseJson);
    String serverId = responseData['id'];
    return serverId;
  }

  Future<String> getServerName() async {
    http.Response response = await valStatus();
    var responseJson = response.body;
    var responseData = jsonDecode(responseJson);
    String serverName = responseData['name'];
    return serverName;
  }
}
