import 'package:flutter_test/flutter_test.dart';

import 'package:valpi/valpi.dart';
import 'package:valpi/players.dart';
import 'package:http/http.dart' as http;

void main() async {
  test('adds one to input values', () async {
    Valpi instance = Valpi(
        "API_KEY", // replace API_KEY with your API Key obtained at https://developer.riotgames.com/
        "SERVER", // replace SERVER keyword with the desired server id, the accepted values are: AP, BR, ESPORTS, EU, KR, LATAM, NA
        locale:
            "LOCALE"); // This argument is optional. You can replace the LOCALE keyword with your desired locale, this is by default set to 'en-GB'.
    // the accepted values for LOCALE are: "ar-AE","de-DE","en-US","es-ES","es-MX","fr-FR","id-ID","it-IT","ja-JP","ko-KR","pl-PL","pt-BR","ru-RU","tr-TR","th-TH","vi-VN","zh-TW"

    print("Server ID: " +
        await instance.getServerId()); //prints the id of the server
    print("Server Name: " +
        await instance.getServerId()); //prints the server name;

    List<String> locales = await instance
        .getAvailableLocales(); // returns all available in the form of a list of Strings
    for (int i = 0; i < locales.length; i++) {
      print("available locales: " + locales[i]);
    }

    List<Players> valorantLeaderBoard = await instance.getValLeaderBoardDataByActId(
        "ab57ef51-4e59-da91-cc8d-51a5a2b9b8ff"); //returns a list of all the players in the leaderboards and their ingame public data of a certain act identified by the act ID. The ID of Episode 1, ACT 2 has been used here.
    for (int i = 0; i < valorantLeaderBoard.length; i++) {
      print("Valorant leaderboard player data for the given act ID.");
      print('------------------------------------------------------\n');
      print("PUUID: " + valorantLeaderBoard[i].puuid);
      print("In Game Name: " + valorantLeaderBoard[i].gameName);
      print("Player Tag Line: " + valorantLeaderBoard[i].tagLine);
      print("Leaderboard Rank: " +
          valorantLeaderBoard[i].leaderboardRank.toString());
      print("Ranked Rating" + valorantLeaderBoard[i].rankedRating.toString());
      print(
          "Number of Wins: " + valorantLeaderBoard[i].numberOfWins.toString());
      print("Competitive Tier: " +
          valorantLeaderBoard[i].competitiveTier.toString());
      print('------------------------------------------------------\n');
    }
    print(await instance.getValActId(
        2)); // gets all the ids of acts as a list and then returns the id on the index indentified by the supplied integer.

    print(await instance.getValLeaderBoardPlayerData(
        2)); // does the same thing as getValLeaderBoardDataByActId(). However, it uses the getValActId() function to use the supplied int to get the id of the act;

    http.Response valStatus = await instance
        .valStatus(); //returns all of the data than can be aquired from /val/status/v1/platform-data in the form of a http response.
    print("Response from /val/status/v1/platform-data: " + valStatus.body);

    http.Response valContent = await instance
        .valStatus(); //returns all of the data than can be aquired from /val/status/v1/contents in the form of a http response.
    print("Response from /val/status/v1/platform-data: " + valContent.body);
  });
}
